@@ -1,4 +1,4 @@
 from description import Description
-from query import Query
+from query import Query, Param
 from client import Client
 from results import Results
