@@ -9,4 +9,4 @@ class ClientTests(TestCase):
         client = Client(ClientTests.url)
         self.assertEqual(client.agent, 'python-opensearch <https://github.com/edsu/opensearch>')
         results = client.search("computer")
-        assert(results.totalResults > 0)
+        self.assertTrue(results.totalResults > 0)
